@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: blt2d.tcl,v 1.29 1998/11/17 21:05:35 jfontain Exp $}
+set rcsId {$Id: blt2d.tcl,v 1.32 1998/11/29 13:44:38 jfontain Exp $}
 
 class blt2DViewer {
 
@@ -17,10 +17,7 @@ if {$::officialBLT} {
         $path yaxis configure -title {} -tickfont $font::(smallNormal)
         $path legend configure -borderwidth 1 -font $font::(mediumNormal) -activebackground white
 
-        # allow dropping of data cells
-        set blt2DViewer::($this,drop) [new dropSite\
-            -path $path -formats DATACELLS -command "viewer::view $this \$dragSite::data(DATACELLS)"\
-        ]
+        viewer::setupDropSite $this $path                                                            ;# allow dropping of data cells
 
         set blt2DViewer::($this,elements) {}                                             ;# initialize list of data line identifiers
         set blt2DViewer::($this,colorIndex) 0
@@ -31,11 +28,10 @@ if {$::officialBLT} {
         if {[info exists blt2DViewer::($this,drag)]} {
             delete $blt2DViewer::($this,drag)
         }
-        delete $blt2DViewer::($this,drop)
+        eval delete $blt2DViewer::($this,elements)                                                       ;# delete existing elements
         if {[info exists blt2DViewer::($this,selector)]} {
             delete $blt2DViewer::($this,selector)
         }
-        eval delete $blt2DViewer::($this,elements)                                                       ;# delete existing elements
     }
 
     proc supportedTypes {this} {
@@ -99,9 +95,6 @@ if {$::officialBLT} {
             selector::remove $blt2DViewer::($this,selector) $element
         }
         unset blt2DViewer::($this,cell,$element)
-        if {[llength $blt2DViewer::($this,elements)]==0} {
-            delete $this                                                            ;# self destruct when there are no more elements
-        }
     }
 
     proc update {this array args} {                                                               ;# update display using cells data
