@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datatab.tcl,v 1.51 1998/11/17 21:05:35 jfontain Exp $}
+set rcsId {$Id: datatab.tcl,v 1.53 1998/11/28 19:25:40 jfontain Exp $}
 
 class dataTable {                       ;# module data view in the form of a table, that can be sorted using a column as a reference
 
@@ -20,7 +20,7 @@ class dataTable {                       ;# module data view in the form of a tab
         set path $composite::($composite::($this,base),scrolled,path)
         # only allow interactive colun resizing
         # use arrow cursor instead of default insertion cursor, meaningless since cell editing is disabled
-        $path configure -font $font::(mediumNormal) -rows 2 -state disabled -titlerows 1 -roworigin -1 -colstretchmode unset\
+        $path configure -font $font::(mediumNormal) -rows 1 -state disabled -titlerows 1 -roworigin -1 -colstretchmode unset\
             -variable dataTable::${this}data -resizeborders col -cursor {} -bordercursor sb_h_double_arrow -highlightthickness 0\
             -takefocus 0
         $path tag configure select -background white
@@ -30,7 +30,7 @@ class dataTable {                       ;# module data view in the form of a tab
         # allow border resizing with first button. does not interfere with drag bindings since command does nothing unless mouse
         # click occured in a column border, which cannot be the case when dragging (see drag validation procedure in this class)
         bind $path <ButtonPress-1> "dataTable::buttonPress $this %x %y"
-        bind $path <Button1-Motion> {%W border dragto %x %y}
+        bind $path <Button1-Motion> "if \$dataTable::($this,columnBorderHit) {%W border dragto %x %y}"
 
         set dataTable::($this,sortOrder) increasing
         set dataTable::($this,tablePath) $path
@@ -260,7 +260,10 @@ class dataTable {                       ;# module data view in the form of a tab
         if {$dataTable::($this,columnBorderHit)} {
             return 0                                                                              ;# resizing a column: prevent drag
         }
-        # allow dragging if only from a selected cell
+        if {[$dataTable::($this,tablePath) cget -rows]<=1} {
+            return 1                                                  ;# allow dragging of empty table (with eventually 1 title row)
+        }
+        # allow dragging only from a selected cell
         return [expr\
             {[lsearch -exact [selector::selected $dataTable::($this,selector)] [$dataTable::($this,tablePath) index @$x,$y]]>=0}\
         ]
@@ -338,7 +341,9 @@ class dataTable {                       ;# module data view in the form of a tab
 
     proc buttonPress {this x y} {
         foreach {row column} [$dataTable::($this,tablePath) border mark $x $y] {}
-        set dataTable::($this,columnBorderHit) [expr {[info exists column]&&([string length $column]>0)}]
+        # do not allow resizing with rightmost column edge
+        set dataTable::($this,columnBorderHit)\
+            [expr {[info exists column]&&([string length $column]>0)&&($column<([$dataTable::($this,tablePath) cget -cols]-1))}]
     }
 
     proc setupDataView {this} {
