@@ -1,10 +1,11 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: diskstats.tcl,v 1.6 1998/12/06 21:37:24 jfontain Exp $}
+set rcsId {$Id: diskstats.tcl,v 1.7 1998/12/12 11:15:11 jfontain Exp $}
 
 package provide diskstats 1.0
 
+package require filesystem
 
 namespace eval diskstats {
 
@@ -90,7 +91,7 @@ SCSI support is not very well tested, for lack of hardware: please report proble
                 if {$scsiFromCharacter($type)||([string length $data($index,5)]==0)} {
                     set data($index,5) $device
                     scan $line {%*u %*u %u} blocks
-                    set data($index,7) [expr {round(($blocks*[lindex [statfs /dev/$device] 0])/1024.0)}]
+                    set data($index,7) [expr {round(($blocks*[lindex [filesystem::statistics /dev/$device] 0])/1024.0)}]
                     if {$scsiFromCharacter($type)} {                                                                         ;# SCSI
                         set file [open /proc/scsi/scsi]
                         gets $file                                                                               ;# skip header line
