@@ -1,7 +1,7 @@
-# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
+# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: html.tcl,v 1.18 1998/11/11 19:55:29 jfontain Exp $}
+set rcsId {$Id: html.tcl,v 1.21 1998/11/17 21:05:35 jfontain Exp $}
 
 # use bold and smaller sizes than the HTML library default ones for headers
 array set HMtag_map {
@@ -41,6 +41,7 @@ proc helpWindow {} {
         return
     }
     toplevel .topHelp
+    wm group .topHelp .                                              ;# for proper window manager (windowmaker for example) behavior
     wm title .topHelp {moodss: Global Help}
     frame .topHelp.bound                      ;# create a frame for bindings that otherwise would propagate to all toplevel children
 
@@ -64,6 +65,7 @@ proc helpWindow {} {
 
     $contentsText configure -state normal
     HMparse_html $::htmlHelpContents "HMrender $contentsText"
+    if {![winfo exists .topHelp]} return                            ;# user may have destroyed the window through the window manager
     $contentsText configure -state disabled
     HMset_state $contentsText -stop 1                                                        ;# stop rendering previous page if busy
 
@@ -76,6 +78,7 @@ proc helpWindow {} {
 
     $htmlHelpDataText configure -state normal
     HMparse_html $::htmlHelpData "HMrender $htmlHelpDataText"
+    if {![winfo exists .topHelp]} return                            ;# user may have destroyed the window through the window manager
     $htmlHelpDataText configure -state disabled
     HMset_state $htmlHelpDataText -stop 1                                                    ;# stop rendering previous page if busy
     focus $htmlHelpDataText                                         ;# force focus on text widget so that page up and down keys work
