@@ -11,9 +11,9 @@ wm group . .
 source utility.tcl
 startGatheringRCSIds
 
-set rcsId {$Id: moodss.tcl,v 1.128 1998/12/10 21:42:34 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.130 1998/12/12 20:49:01 jfontain Exp $}
 
-set applicationVersion 5.4
+set applicationVersion 5.5
 
 source getopt.tcl
 
@@ -534,7 +534,7 @@ foreach module $modules(all) {
         } else {                                                                                     ;# use single default data view
             set table [new dataTable $canvas -data ${module}::data -draggable $draggable]
         }
-        if {[info exists initializer]&&([lsearch -exact $module $modules(initialized)]>=0)} {
+        if {[info exists initializer]&&([lsearch -exact $modules(initialized) $module]>=0)} {    ;# setup initialized modules tables
             eval composite::configure $table [record::tableOptions $initializer $module $index]
             # use stored window manager initialization data for table
             foreach {x y width height level} [record::tableWindowManagerData $initializer $module $index] {}
