@@ -1,7 +1,7 @@
-# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
+# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.10 1998/11/03 20:23:37 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.13 1998/11/23 21:56:27 jfontain Exp $}
 
 
 class record {
@@ -45,8 +45,9 @@ class record {
                 # filter other module tables
                 if {[string compare $module [namespace qualifiers [composite::cget $table -data]]]!=0} continue
                 foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($table,path)] {}
+                set level [canvasWindowManager::getStackLevel $::windowManager $widget::($table,path)]
                 puts $file "            $table \{"
-                puts $file "                x $x y $y width $width height $height"
+                puts $file "                x $x y $y width $width height $height level $level"
                 foreach {switch value} [dataTable::initializationConfiguration $table] {
                     puts $file "                $switch [list $value]"
                 }
@@ -61,7 +62,8 @@ class record {
             puts $file "    $viewer \{"
             puts $file "        class [classof $viewer]"
             foreach {x y width height} [canvasWindowManager::getGeometry $::windowManager $widget::($viewer,path)] {}
-            puts $file "        x $x y $y width $width height $height"
+            set level [canvasWindowManager::getStackLevel $::windowManager $widget::($viewer,path)]
+            puts $file "        x $x y $y width $width height $height level $level"
             puts $file "        cells {[viewer::cells $viewer]}"
             foreach {switch value} [viewer::initializationConfiguration $viewer] {
                 puts $file "        $switch [list $value]"
@@ -110,12 +112,13 @@ class record {
         set list {}
         foreach id [lsort -integer [array names data]] {
             catch {unset viewer}
+            set viewer(level) {}        ;# for backward compatibility when level was not stored in save file (versions 5.1 and down)
             array set viewer $data($id)
             set options {}                                  ;# gather viewer specific switched options in a switch / value pair list
             foreach name [array names viewer -*] {
                 lappend options $name $viewer($name)
             }
-            lappend list $viewer(class) $viewer(cells) $viewer(x) $viewer(y) $viewer(width) $viewer(height) $options
+            lappend list $viewer(class) $viewer(cells) $viewer(x) $viewer(y) $viewer(width) $viewer(height) $viewer(level) $options
         }
         return $list
     }
@@ -129,13 +132,14 @@ class record {
         unset data
         array set tablesData $moduleData(tables)
         unset moduleData
+        set data(level) {}              ;# for backward compatibility when level was not stored in save file (versions 5.1 and down)
         # use table identifier at the specified index in creation order sorted table indices
         array set data $tablesData([lindex [lsort -integer [array names tablesData]] $creationIndex])
     }
 
-    proc tableGeometry {this module creationIndex} {
+    proc tableWindowManagerData {this module creationIndex} {
         tableData $this $module $creationIndex data
-        return [list $data(x) $data(y) $data(width) $data(height)]
+        return [list $data(x) $data(y) $data(width) $data(height) $data(level)]
     }
 
     proc tableOptions {this module creationIndex} {
